summaryrefslogtreecommitdiff
path: root/src/testing/testing_api_cmd_set_wire_fee.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/testing/testing_api_cmd_set_wire_fee.c')
-rw-r--r--src/testing/testing_api_cmd_set_wire_fee.c70
1 files changed, 41 insertions, 29 deletions
diff --git a/src/testing/testing_api_cmd_set_wire_fee.c b/src/testing/testing_api_cmd_set_wire_fee.c
index 8eb993878..460a71e40 100644
--- a/src/testing/testing_api_cmd_set_wire_fee.c
+++ b/src/testing/testing_api_cmd_set_wire_fee.c
@@ -61,11 +61,6 @@ struct WireFeeState
const char *closing_fee;
/**
- * Wad fee amount to use.
- */
- const char *wad_fee;
-
- /**
* Expected HTTP response code.
*/
unsigned int expected_response_code;
@@ -82,27 +77,21 @@ struct WireFeeState
* if the response code is acceptable.
*
* @param cls closure.
* @param hr HTTP response details
*/
static void
wire_add_cb (void *cls,
- const struct TALER_EXCHANGE_HttpResponse *hr)
+ const struct TALER_EXCHANGE_ManagementSetWireFeeResponse *sfr)
{
struct WireFeeState *ds = cls;
+ const struct TALER_EXCHANGE_HttpResponse *hr = &sfr->hr;
ds->dh = NULL;
if (ds->expected_response_code != hr->http_status)
{
- GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
- "Unexpected response code %u to command %s in %s:%u\n",
- hr->http_status,
- ds->is->commands[ds->is->ip].label,
- __FILE__,
- __LINE__);
- json_dumpf (hr->reply,
- stderr,
- 0);
- TALER_TESTING_interpreter_fail (ds->is);
+ TALER_TESTING_unexpected_status (ds->is,
+ hr->http_status,
+ ds->expected_response_code);
return;
}
TALER_TESTING_interpreter_next (ds->is);
@@ -127,8 +116,24 @@ wire_add_run (void *cls,
struct GNUNET_TIME_Timestamp start_time;
struct GNUNET_TIME_Timestamp end_time;
struct TALER_WireFeeSet fees;
+ const char *exchange_url;
(void) cmd;
+ {
+ const struct TALER_TESTING_Command *exchange_cmd;
+
+ exchange_cmd = TALER_TESTING_interpreter_get_command (is,
+ "exchange");
+ if (NULL == exchange_cmd)
+ {
+ GNUNET_break (0);
+ TALER_TESTING_interpreter_fail (is);
+ return;
+ }
+ GNUNET_assert (GNUNET_OK ==
+ TALER_TESTING_get_trait_exchange_url (exchange_cmd,
+ &exchange_url));
+ }
ds->is = is;
now = GNUNET_TIME_absolute_get ();
start_time = GNUNET_TIME_absolute_to_timestamp (
@@ -141,9 +146,6 @@ wire_add_run (void *cls,
TALER_string_to_amount (ds->closing_fee,
&fees.closing)) ||
(GNUNET_OK !=
- TALER_string_to_amount (ds->wad_fee,
- &fees.wad)) ||
- (GNUNET_OK !=
TALER_string_to_amount (ds->wire_fee,
&fees.wire)) )
{
@@ -160,16 +162,30 @@ wire_add_run (void *cls,
}
else
{
+ const struct TALER_TESTING_Command *exchange_cmd;
+ const struct TALER_MasterPrivateKeyP *master_priv;
+
+ exchange_cmd = TALER_TESTING_interpreter_get_command (is,
+ "exchange");
+ if (NULL == exchange_cmd)
+ {
+ GNUNET_break (0);
+ TALER_TESTING_interpreter_fail (is);
+ return;
+ }
+ GNUNET_assert (GNUNET_OK ==
+ TALER_TESTING_get_trait_master_priv (exchange_cmd,
+ &master_priv));
TALER_exchange_offline_wire_fee_sign (ds->wire_method,
start_time,
end_time,
&fees,
- &is->master_priv,
+ master_priv,
&master_sig);
}
ds->dh = TALER_EXCHANGE_management_set_wire_fees (
- is->ctx,
- is->exchange_url,
+ TALER_TESTING_interpreter_get_context (is),
+ exchange_url,
ds->wire_method,
start_time,
end_time,
@@ -201,10 +217,8 @@ wire_add_cleanup (void *cls,
if (NULL != ds->dh)
{
- GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
- "Command %u (%s) did not complete\n",
- ds->is->ip,
- cmd->label);
+ TALER_TESTING_command_incomplete (ds->is,
+ cmd->label);
TALER_EXCHANGE_management_set_wire_fees_cancel (ds->dh);
ds->dh = NULL;
}
@@ -217,7 +231,6 @@ TALER_TESTING_cmd_set_wire_fee (const char *label,
const char *wire_method,
const char *wire_fee,
const char *closing_fee,
- const char *wad_fee,
unsigned int expected_http_status,
bool bad_sig)
{
@@ -229,7 +242,6 @@ TALER_TESTING_cmd_set_wire_fee (const char *label,
ds->wire_method = wire_method;
ds->wire_fee = wire_fee;
ds->closing_fee = closing_fee;
- ds->wad_fee = wad_fee;
{
struct TALER_TESTING_Command cmd = {
.cls = ds,
@@ -82,27 +77,21 @@ struct WireFeeState
*
* @param cls closure.
- * @param hr HTTP response details
+ * @param sfr response details
*/
static void